<?php
require_once( LIB_DIR . 'Prototype' . DS . 'class.PTPlugin.php' );

class PHPFatalErrorNotification extends PTPlugin
{
    private $from_email = null;
    private $to_email   = null;

    public function __construct ()
    {
        parent::__construct();
    }

    public function start_app ( $app ) : void
    {
        $error = '';
        $from = $app->system_email( $error );
        $to = $this->get_config_value( 'phpfatalerrornotification_email', 0 );
        if (
          $from && $app->is_valid_email( $from, $error )
       && $to   && $app->is_valid_email( $to, $error )
        ) {
            $this->from_email = $from;
            $this->to_email = $to;
            register_shutdown_function( [$this, 'shutdown_function'] );
        }
    }

    public function shutdown_function () : void
    {
        $error = error_get_last();
        if ( $error === null || $error['type'] !== E_ERROR ) return;
        if ( !$this->to_email || !$this->from_email ) return;
        $subject = 'A fatal PHP error occurred';
        $body = '[' . date( 'c' ) . '] ' . PHP_EOL
              . $error['message'] . ' in ' . $error['file'] . ' on line ' . $error['line'] . PHP_EOL;
        $options = ['From' => $this->from_email];
        PTUtil::send_mail( $this->to_email, $subject, $body, $options );
    }
}
